@@ -70,7 +70,7 @@ void ls_stderr(const char * fmt, ...)
     vsnprintf(buf, sizeof(buf), fmt, ap);
     va_end(ap);
     fprintf(stderr, "%s", buf);
-    DEBUG_MESSAGE("stderr message: %s", buf);
+    //DEBUG_MESSAGE("stderr message: %s", buf);
 }
 
 static uid_t        s_uid;
