@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -195,8 +195,10 @@ class RewriteRule : public LinkedObj
 
     int parseRuleSubst(const char *&pRuleStr, const char *pEnd,
                        const RewriteMapList *pMaps);
-    int parseRuleFlag(const char *&pRuleStr, const char *pEnd);
-    int parseOneFlag(const char *&pRuleStr, const char *pEnd);
+    int parseRuleFlag(const char *&pRuleStr, const char *pEnd,
+                      const RewriteMapList *pMaps);
+    int parseOneFlag(const char *&pRuleStr, const char *pEnd,
+                     const RewriteMapList *pMaps);
     int compilePattern();
     void operator=(const RewriteRule &rhs);
 
