@@ -39,6 +39,14 @@ enum H2FrameType
     H2_FRAME_WINDOW_UPDATE, //8,
     H2_FRAME_CONTINUATION,  //9,
     H2_FRAME_MAX_TYPE,      //10
+    H2_FRAME_GREASE0 = 0xb, //11
+    H2_FRAME_GREASE1 = H2_FRAME_GREASE0 + 0x1f,
+    H2_FRAME_GREASE2 = H2_FRAME_GREASE1 + 0x1f,
+    H2_FRAME_GREASE3 = H2_FRAME_GREASE2 + 0x1f,
+    H2_FRAME_GREASE4 = H2_FRAME_GREASE3 + 0x1f,
+    H2_FRAME_GREASE5 = H2_FRAME_GREASE4 + 0x1f,
+    H2_FRAME_GREASE6 = H2_FRAME_GREASE5 + 0x1f,
+    H2_FRAME_GREASE7 = H2_FRAME_GREASE6 + 0x1f,
 };
 // Flags on data packets.
 enum H2DataFlags
